{% load i18n %}{% blocktrans with message.recipient.username as recipient and message.sender.username as sender%}Hello {{ recipient }},

you received a private message from {{ sender }} with
the following contents:{% endblocktrans %}

{{ message.body|safe }}

--
{% blocktrans %}Sent from {{ site_url }}{% endblocktrans %}
{% trans "Inbox" %}: {{ site_url }}{% url messages_inbox %}
{% trans "Reply" %}: {{ site_url }}{% url messages_reply message.pk %}     