{% extends "django_messages/base.html" %}
{% load i18n %} 
{% block body %} 
<h1>{% trans "Deleted Messages" %}</h1>
<table class="messages">
    <thead>
        <tr><th>{% trans "Sender" %}</th><th>{% trans "Subject" %}</th><th>{% trans "Date" %}</th><th>{% trans "Action" %}</th></tr>
    </thead>
    <tbody>
{% for message in message_list %} 
    <tr>
        <td>{{ message.sender }}</td>
        <td> 
        {{ message.subject }}
        </td>
        <td>{{ message.sent_at|date:_("DATETIME_FORMAT") }}</td>
        <td><a href="{% url messages_undelete message.id %}">{% trans "undelete" %}</a></td>
    </tr>
{% endfor %}
    </tbody>
</table>
<br />
<p>{% trans "Deleted Messages are removed from the trash at unregular intervals, don't rely on this feature for long-time storage." %}</p>
{% endblock %}